@@ -160,6 +160,7 @@ class SetupSelenium:
     @staticmethod
     def log_options(options: ArgOptions) -> None:
         """Logs the browser option in clean format"""
+        # logger.debug(f"{json.dumps(options.capabilities, indent=2)}")  # noqa: ERA001
         opts = "\n".join(options.arguments)
         logger.debug(f"{opts}")
 
@@ -279,6 +280,27 @@ class SetupSelenium:
         options.set_preference("app.update.enabled", False)
         options.set_preference("network.prefetch-next", False)
         options.set_preference("network.dns.disablePrefetch", True)
+        options.set_preference(
+            "extensions.formautofill.addresses.capture.enabled", False
+        )
+        # By default, headless Firefox runs as though no pointers capabilities
+        # are available.
+        # https://github.com/microsoft/playwright/issues/7769#issuecomment-966098074
+        #
+        # This impacts React Spectrum which uses an '(any-pointer: fine)'
+        # media query to determine font size. It also causes certain chart
+        # elements to always be visible that should only be visible on
+        # hover.
+        #
+        # Available values for pointer capabilities:
+        # NO_POINTER             0x00
+        # COARSE_POINTER         0x01
+        # FINE_POINTER           0x02
+        # HOVER_CAPABLE_POINTER  0x04
+        #
+        # Setting to 0x02 | 0x04 says the system supports a mouse
+        options.set_preference("ui.primaryPointerCapabilities", 0x02 | 0x04)
+        options.set_preference("ui.allPointerCapabilities", 0x02 | 0x04)
         return options
 
     @staticmethod
@@ -335,9 +357,29 @@ class SetupSelenium:
     def chrome_options() -> webdriver.ChromeOptions:
         """Default options for chrome"""
         logger.debug("Setting up chrome options")
+        # the ultimate list of flags (created by the chromium dev group)
+        # https://peter.sh/experiments/chromium-command-line-switches/
+
         # The list of options set below mostly came from this StackOverflow post
         # https://stackoverflow.com/q/48450594/2532408
         opts = (
+            # "--disable-features=ImprovedCookieControls,LazyFrameLoading,GlobalMediaControls,DestroyProfileOnBrowserClose,MediaRouter,DialMediaRouteProvider,AcceptCHFrame,AutoExpandDetailsElement,CertificateTransparencyComponentUpdater,AvoidUnnecessaryBeforeUnloadCheckSync",  # noqa: ERA001
+            "--disable-back-forward-cache",
+            "--disable-background-timer-throttling",
+            "--disable-breakpad",
+            "--disable-component-extensions-with-background-pages",
+            "--disable-ipc-flooding-protection",
+            "--enable-features=NetworkService,NetworkServiceInProcess",
+            "--enable-logging",
+            "--export-tagged-pdf",
+            "--force-color-profile=srgb",
+            "--metrics-recording-only",
+            "--mute-audio",
+            "--remote-debugging-pipe",
+            # fixes MUI fade issue
+            "--disable-renderer-backgrounding",
+            # fixes actionchains in headless
+            "--disable-backgrounding-occluded-windows",
             "--disable-extensions",
             "--allow-running-insecure-content",
             "--ignore-certificate-errors",
@@ -351,9 +393,11 @@ class SetupSelenium:
             # it's possible we no longer need to do these
             "--disable-gpu",  # https://stackoverflow.com/q/51959986/2532408
         )
+        exp_prefs = {"autofill.profile_enabled": False}
         options = webdriver.ChromeOptions()
         for opt in opts:
             options.add_argument(opt)
+        options.add_experimental_option("prefs", exp_prefs)
         return options
 
     @staticmethod
@@ -373,7 +417,7 @@ class SetupSelenium:
             options.binary_location = binary
 
         if headless:
-            options.add_argument("--headless")
+            options.add_argument("--headless=new")
 
         logging_prefs = {"browser": "OFF", "performance": "OFF", "driver": "OFF"}
 
@@ -470,9 +514,29 @@ class SetupSelenium:
     def edge_options() -> webdriver.EdgeOptions:
         """Default options for edgedriver"""
         logger.debug("Setting up edge options")
+        # the ultimate list of flags (created by the chromium dev group)
+        # https://peter.sh/experiments/chromium-command-line-switches/
+
         # The list of options set below mostly came from this StackOverflow post
         # https://stackoverflow.com/q/48450594/2532408
         opts = (
+            # "--disable-features=ImprovedCookieControls,LazyFrameLoading,GlobalMediaControls,DestroyProfileOnBrowserClose,MediaRouter,DialMediaRouteProvider,AcceptCHFrame,AutoExpandDetailsElement,CertificateTransparencyComponentUpdater,AvoidUnnecessaryBeforeUnloadCheckSync",  # noqa: ERA001
+            "--disable-back-forward-cache",
+            "--disable-background-timer-throttling",
+            "--disable-breakpad",
+            "--disable-component-extensions-with-background-pages",
+            "--disable-ipc-flooding-protection",
+            "--enable-features=NetworkService,NetworkServiceInProcess",
+            "--enable-logging",
+            "--export-tagged-pdf",
+            "--force-color-profile=srgb",
+            "--metrics-recording-only",
+            "--mute-audio",
+            "--remote-debugging-pipe",
+            # fixes MUI fade issue
+            "--disable-renderer-backgrounding",
+            # fixes actionchains in headless
+            "--disable-backgrounding-occluded-windows",
             "--disable-extensions",
             "--allow-running-insecure-content",
             "--ignore-certificate-errors",
@@ -484,9 +548,11 @@ class SetupSelenium:
             "--no-sandbox",
             "--disable-dev-shm-usage",
         )
+        exp_prefs = {"autofill.profile_enabled": False}
         options = webdriver.EdgeOptions()
         for opt in opts:
             options.add_argument(opt)
+        options.add_experimental_option("prefs", exp_prefs)
         return options
 
     @staticmethod
@@ -516,12 +582,11 @@ class SetupSelenium:
         # by default performance is disabled.
         if enable_log_performance:
             logging_prefs["performance"] = "ALL"
-            options.set_capability(
+            options.add_experimental_option(
                 "perfLoggingPrefs",
                 {
                     "enableNetwork": True,
                     "enablePage": False,
-                    "enableTimeline": False,
                 },
             )
 
@@ -587,7 +652,7 @@ class SetupSelenium:
 
     def set_main_window_handle(self, window: str | None = None) -> str:
         """
-        maintains the initial window handle as an attribute
+        Maintains the initial window handle as an attribute
 
         Most users will never utilize this. It's part of a legacy requirement for
         an old test suite
@@ -599,7 +664,7 @@ class SetupSelenium:
             except NoSuchWindowException:
                 try:
                     window = self.driver.window_handles[0]
-                except WebDriverException:  # noqa: TRY302
+                except WebDriverException:  # noqa: TRY203
                     # Have we closed all the windows?
                     raise
         if window:
